<?php
/*

	Digistr.API Client 1.0
	http://digistr.ru/dev/app

*/


class DigistrException extends Exception {}


class DigistrAPI
{
    const STATUS_SUCCESS = 'success';
    const API_VERSION = '2.3';

	protected $appSecret = null;
	protected $siteId = null;
	protected $sitePassword = null;
	protected $siteHost = null;

	private $lastError = null;


	function __construct($appId = null, $appSecret = null, $siteId = null, $sitePassword = null, $siteHost = null)
	{
		if (!$appId || !$appSecret || !$siteId || !$sitePassword || !$siteHost)
			throw new DigistrException('$appId, $appSecret, $siteId, $sitePassword and $siteHost are required.');

		$this->appId = $appId;
		$this->appSecret = $appSecret;
		$this->siteId = $siteId;
		$this->sitePassword  = $sitePassword;
		$this->siteHost  = $siteHost;
	}


	public function query($method, $params = array())
	{
		try
		{
			$result = $this->__request($method, $params);
			$result = $result['data'];

		}
		catch (DigistrException $e)
		{
			$this->lastError = $e->getMessage();
		}

		return $result;
	}

	public function getError()
	{
		return $this->lastError;
	}




	protected function __getUrl($method)
	{
		$url = 'http://' . $this->siteHost . '/api/' . self::API_VERSION . '/' . $method . '.json';

		return $url;
	}


	private function __request($method, $params)
	{
		$ch = curl_init();
		curl_setopt($ch, CURLOPT_URL, $this->__getUrl($method));
		curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
		curl_setopt($ch, CURLOPT_USERAGENT, 'Digistr API/1.0 Client');
		curl_setopt($ch, CURLOPT_FAILONERROR, 1);
		curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, 0);
		curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, 0);
		curl_setopt($ch, CURLOPT_FOLLOWLOCATION, 1);
		curl_setopt($ch, CURLOPT_HEADER, 0);

		$params['auth'] = array(
				'app_id' => $this->appId,
				'method' => $method,
				'token' => md5($method . ':' . $this->appId . ':' . $this->appSecret . ':' . $this->sitePassword),
		);

		curl_setopt($ch, CURLOPT_POST, true);
		curl_setopt($ch, CURLOPT_POSTFIELDS, http_build_query($params));

		$result = curl_exec($ch);
		curl_close($ch);

		if ($result)
		{
			$result = json_decode($result, true);

			if ($result['status'] != self::STATUS_SUCCESS)
	            throw new DigistrException($result['message']);
			else
				return $result;
		}

		return false;

    }


}
?>